<?xml version="1.0" encoding="UTF-8" ?>
<!-- 
*
**********************************************************************    
*  
*   Licensed Material - Property of IBM                               
*   5655-002                                                          
*                                                                     
*   (C) Copyright IBM Corp. 2003   All Rights Reserved                
*                                                                     
*   US Government Users Restricted Rights - Use, duplication or       
*   disclosure restricted by GSA ASP Schedule Contract with           
*   IBM Corp.    
*
**********************************************************************                                                     
*                                                                           
* IBM Document Connect for ASF                                                 
*                                                                              
* Module Name : docbase.xsl                                                  
*                                                                              
* Description : This style sheet contains basic template rules

*
* Author:       UZeh
*
* Change Activity:                                                             
*                                                                              
* Code  Release    Date       Person  Reason                                   
*                                                                              
* @000  V01R01B07  10/13/2005 UZeh    DPTR5130 PTR5130 Create common rules fxYYYYY
* @001  V01R01B07  02/13/2006 UZeh    DPK17220 PTR5419 Add rule fxGetCurrentTimestamp 
* @002  1.2.2      2006-04-10 MMar    DPK22286 Encoding changed to UTF-8 
* @003  1.2.2      2006-05-31 UZeh    DPTR5666 Description corrected, fxButton, fxHidden, fxCheckbox, fxPassword added  
* @004  1.2.2      2006-06-21 UZeh    DPTR5700 fxCheckbox. New parameters xcbfnOnClick xcbfnOnKeyPress                   
*
*-->

<!-- @001 Add Extension Namespace ( for future use) -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:xalan="http://xml.apache.org/xalan"
                xmlns:java="http://xml.apache.org/xalan/java"
                xmlns:str="http://exslt.org/strings"
                xmlns:exsl="http://exslt.org/common"
                xmlns:math="http://exslt.org/math"
                xmlns:set="http://exslt.org/sets"
                extension-element-prefixes="date xalan java str exsl math set"           
                version="1.0">

<!-- ************************************************************** -->
<!--                                                                -->
<!--                                                                -->  
<!-- This is the template rule called                               --> 
<!--     fxCurrentTimestamp                                         --> 
<!-- which returns the current timestamp                            -->
<!--                                                                --> 
<!-- ************************************************************** -->   

<xsl:template name = "fxGetCurrentTimestamp">
    
     
    <xsl:value-of select="java:getTime(java:java.util.Date.new())"/> 


</xsl:template>





<!-- ************************************************************** -->
<!--                                                                -->
<!--                                                                -->  
<!-- This is the template rule called                               --> 
<!--     fxButton                                                   --> 
<!-- which displays a HTML input button                             -->
<!--                                                                --> 
<!-- Parameters                                                     -->
<!--                                                                -->
<!--     xbtfid       Button id                                     -->
<!--     xbtfnm       Button name                                   -->
<!--     xbtfro       Button field readonly  Y or N                 -->
<!--     xbtfsz       Button size                                   -->
<!--     xbtfva       Button value                                  -->
<!--     xbtbfnOnKeyPress  onKeyPress function                      -->  
<!--     xbtbfnOnClick     onClick function                         --> 
<!-- ************************************************************** -->                     
 


<xsl:template name = "fxButton"> 

    
    <xsl:param name = "xbtfid"/> 
    <xsl:param name = "xbtfty"/> 
    <xsl:param name = "xbtfnm"/>     
    <xsl:param name = "xbtfsz"/>   
    <xsl:param name = "xbtfva"/>
    <xsl:param name = "xbtfnOnKeyPress"/>
    <xsl:param name = "xbtfnOnClick"/>

    <xsl:element name = "input" > 
      <xsl:attribute name = "id" ><xsl:value-of select= "$xbtfid"/></xsl:attribute> 
      <xsl:attribute name = "type" ><xsl:value-of select= "$xbtfty"/></xsl:attribute> 
      <xsl:attribute name = "name" ><xsl:value-of select= "$xbtfnm"/></xsl:attribute> 
      <xsl:attribute name = "size" ><xsl:value-of select= "$xbtfsz"/></xsl:attribute>  
      <xsl:attribute name = "value"><xsl:value-of select= "$xbtfva"/></xsl:attribute> 
      <xsl:attribute name = "onclick" ><xsl:value-of select= "$xbtfnOnClick"/></xsl:attribute> 
      <xsl:attribute name = "onkeypress" ><xsl:value-of select= "$xbtfnOnKeyPress"/></xsl:attribute>
   </xsl:element>
</xsl:template>

<!-- ************************************************************** -->
<!--                                                                -->
<!--                                                                -->  
<!-- This is the template rule called                               --> 
<!--     fxCheckbox                                                 --> 
<!-- which displays a HTML input type=text tag                      -->
<!--                                                                --> 
<!-- Parameters                                                     -->
<!--                                                                -->
<!--     xcbfid      Checkbox id                                    -->
<!--     xcbfnm      Checkbox name                                  -->
<!--     xcbfcc      Checkbox checked criterion ( Y or N )          -->
<!--     xcbfdc      Checkbox disabled criterion ( Y or N )         -->
<!--     xcbfnOnKeyPress  onKeyPress function                       --> 
<!--     xcbfnOnClick     onClick function                          --> 
<!-- ************************************************************** -->   
       
<xsl:template name = "fxCheckbox">        

    <xsl:param name = "xcbfid"/>   
    <xsl:param name = "xcbfnm"/>     
    <xsl:param name = "xcbfcc"/>   
    <xsl:param name = "xcbfdc"/>   
    <xsl:param name = "xcbfnOnKeyPress"/>
    <xsl:param name = "xcbfnOnClick"/>

   <xsl:element name = "input" > 
      <xsl:attribute name = "type" >checkbox</xsl:attribute> 
      <xsl:attribute name = "name" ><xsl:value-of select="$xcbfnm"/></xsl:attribute>   
      <xsl:attribute name = "id"   ><xsl:value-of select="$xcbfid"/></xsl:attribute>   
      <xsl:if test="$xcbfcc='Y'">
        <xsl:attribute name = "checked">checked</xsl:attribute>
      </xsl:if> 
      <xsl:if test="$xcbfdc='Y'">
        <xsl:attribute name = "disabled">disabled</xsl:attribute>
      </xsl:if>
      <xsl:attribute name = "onclick" ><xsl:value-of select= "$xcbfnOnClick"/></xsl:attribute> 
      <xsl:attribute name = "onkeypress" ><xsl:value-of select= "$xcbfnOnKeyPress"/></xsl:attribute>
   </xsl:element>
 
</xsl:template>

<!-- ************************************************************** -->
<!--                                                                -->
<!--                                                                -->  
<!-- This is the template rule called                               --> 
<!--     fxHidden                                                   --> 
<!-- which displays a hidden HTML input type=text tag               -->
<!--                                                                --> 
<!-- Parameters                                                     -->
<!--                                                                -->
<!--     xhdfid      Hidden Input field id                          -->
<!--     xhdfnm      Hidden Input field name                        -->
<!--     xhdfro      Hidden Input field readonly  Y or N            -->
<!--     xhdfsz      Hidden Input field size                        -->
<!--     xhdfmx      Hidden Input field maxlength                   -->
<!--     xhdfva      Hidden Input field value                       -->
<!-- ************************************************************** -->   


<xsl:template name = "fxHidden"> 
    
    <xsl:param name = "xhdfid"/> 
    <xsl:param name = "xhdfnm"/>  
    <xsl:param name = "xhdfro"/>              
    <xsl:param name = "xhdfsz"/>
    <xsl:param name = "xhdfmx"/> 
    <xsl:param name = "xhdfva"/>

      <xsl:element name = "input" > 
         <xsl:attribute name = "type" >hidden</xsl:attribute> 
         <xsl:attribute name = "id"   ><xsl:value-of select="$xhdfid"/></xsl:attribute> 
         <xsl:attribute name = "name" ><xsl:value-of select="$xhdfnm"/></xsl:attribute>       
         <xsl:attribute name = "size" ><xsl:value-of select="$xhdfsz"/></xsl:attribute> 
         <xsl:attribute name = "maxlength" ><xsl:value-of select="$xhdfmx"/></xsl:attribute> 
         <xsl:attribute name = "value"><xsl:value-of select="$xhdfva"/></xsl:attribute>
         <xsl:if test="$xhdfro='Y'">    
            <xsl:attribute name = "readonly" >readonly</xsl:attribute>
         </xsl:if>     
      </xsl:element> 
</xsl:template>

<!-- ************************************************************** -->
<!--                                                                -->
<!--                                                                -->  
<!-- This is the template rule called                               --> 
<!--     fxInput                                                    --> 
<!-- which displays a HTML input type=text tag                      -->
<!--                                                                --> 
<!-- Parameters                                                     -->
<!--                                                                -->
<!--     xipfid      Input field id                                 -->
<!--     xipfnm      Input field name                               -->
<!--     xipfro      Input field readonly  Y or N                   -->
<!--     xipfsz      Input field size                               -->
<!--     xipfmx      Input field maxlength                          -->
<!--     xipfva      Input field value                              -->
<!--     xipfnOnBlur onBlur function                                -->  
<!-- ************************************************************** -->                     
 

<xsl:template name = "fxInput"> 

  
    <xsl:param name = "xipfid"/> 
    <xsl:param name = "xipfnm"/>  
    <xsl:param name = "xipfro"/>              
    <xsl:param name = "xipfsz"/>
    <xsl:param name = "xipfmx"/> 
    <xsl:param name = "xipfva"/>
    <xsl:param name = "xipfnOnBlur"/>
        
    
    <xsl:element name="input">
             <xsl:attribute name="id"><xsl:value-of select="$xipfid"/></xsl:attribute> 
             <xsl:attribute name="type">text</xsl:attribute> 
             <xsl:attribute name="name"><xsl:value-of select="$xipfnm"/></xsl:attribute> 
             <xsl:if test="$xipfro='Y'">
                <xsl:attribute name="readonly">readonly</xsl:attribute> 
             </xsl:if> 
             <xsl:attribute name="size"><xsl:value-of select="$xipfsz"/></xsl:attribute> 
             <xsl:attribute name="maxlength"><xsl:value-of select="$xipfmx"/></xsl:attribute> 
             <xsl:attribute name="value"><xsl:value-of select="$xipfva"/></xsl:attribute>         
             <xsl:attribute name="onblur"><xsl:value-of select="$xipfnOnBlur"/></xsl:attribute>           
   </xsl:element>  
          
</xsl:template>


<!-- ************************************************************** -->
<!--                                                                -->
<!--                                                                -->  
<!-- This is the template rule called                               --> 
<!--     fxLabel                                                    --> 
<!-- which creates a HTML label   tag                               -->
<!--                                                                --> 
<!-- Parameters                                                     -->
<!--                                                                -->
<!--     xlblid      Label field id                                 -->
<!--     xlblva      Label field value ( Name of label )            -->
<!-- ************************************************************** -->   

<xsl:template name = "fxLabel">
    
    <xsl:param name = "xlblid"/> 
    <xsl:param name = "xlblfo"/>
    <xsl:param name = "xlblva"/>

     <xsl:element name="label">
        <xsl:if test="$xlblfo != ''">   
            <xsl:attribute name="for"><xsl:value-of select="$xlblfo"/></xsl:attribute>
        </xsl:if>   
        <xsl:attribute name="id"><xsl:value-of select="$xlblid"/></xsl:attribute>
        <xsl:value-of select= "$xlblva"/>   
     </xsl:element> 


</xsl:template>

<!-- ************************************************************** -->
<!--                                                                -->
<!--                                                                -->  
<!-- This is the template rule called                               --> 
<!--     fxPassword                                                 --> 
<!-- which displays a HTML input type=password tag                  -->
<!--                                                                --> 
<!-- Parameters                                                     -->
<!--                                                                -->
<!--     xipfid      Input field id                                 -->
<!--     xipfnm      Input field name                               -->
<!--     xipfro      Input field readonly  Y or N                   -->
<!--     xipfsz      Input field size                               -->
<!--     xipfmx      Input field maxlength                          -->
<!--     xipfva      Input field value                              -->
<!--     xipfnOnBlur onBlur function                                -->  
<!-- ************************************************************** -->                     
 

<xsl:template name = "fxPassword"> 

  
    <xsl:param name = "xipfid"/> 
    <xsl:param name = "xipfnm"/>  
    <xsl:param name = "xipfro"/>              
    <xsl:param name = "xipfsz"/>
    <xsl:param name = "xipfmx"/> 
    <xsl:param name = "xipfva"/>
    <xsl:param name = "xipfnOnBlur"/>
        
    
    <xsl:element name="input">
             <xsl:attribute name="id"><xsl:value-of select="$xipfid"/></xsl:attribute> 
             <xsl:attribute name="type">password</xsl:attribute> 
             <xsl:attribute name="name"><xsl:value-of select="$xipfnm"/></xsl:attribute> 
             <xsl:if test="$xipfro='Y'">
                <xsl:attribute name="readonly">readonly</xsl:attribute> 
             </xsl:if> 
             <xsl:attribute name="size"><xsl:value-of select="$xipfsz"/></xsl:attribute> 
             <xsl:attribute name="maxlength"><xsl:value-of select="$xipfmx"/></xsl:attribute> 
             <xsl:attribute name="value"><xsl:value-of select="$xipfva"/></xsl:attribute>         
             <xsl:attribute name="onblur"><xsl:value-of select="$xipfnOnBlur"/></xsl:attribute>           
   </xsl:element>  
          
</xsl:template>


<!-- ************************************************************** -->
<!--                                                                -->
<!--                                                                -->  
<!-- This is the template rule called                               --> 
<!--     fxTextarea                                                 --> 
<!-- which creates a HTML textarea tag                              -->
<!--                                                                --> 
<!-- Parameters                                                     -->
<!--                                                                -->
<!--     xtafid      Textarea field id                              -->
<!--     xtafnm      Textarea field name                            -->
<!--     xtafrw      Textarea field number of rows                  -->
<!--     xtafco      Textarea field number of columns               -->
<!--     xtafva      Textarea field value                           -->
<!--     xtafro      Textarea field is readonly     Y or N          -->
<!--     xtafnOnBlur onBlur function                                -->  
<!-- ************************************************************** -->


<xsl:template name = "fxTextarea"> 
   
    <xsl:param name = "xtafid" />
    <xsl:param name = "xtafnm" />   
    <xsl:param name = "xtafrw" />
    <xsl:param name = "xtafco" />
    <xsl:param name = "xtafva" />
    <xsl:param name = "xtafro" />
    <xsl:param name = "xtafnOnBlur" />

    
    <xsl:element name="textarea">

            <xsl:attribute name="id"><xsl:value-of select="$xtafid"/></xsl:attribute> 
            <xsl:attribute name="name"><xsl:value-of select="$xtafnm"/></xsl:attribute>            
            <xsl:attribute name="UNSELECTABLE">off</xsl:attribute> 
            <xsl:if test="$xtafro='Y'">
                <xsl:attribute name="readonly">readonly</xsl:attribute> 
            </xsl:if>     
            <xsl:value-of select="$xtafva"/>
            <xsl:attribute name="rows"><xsl:value-of select="$xtafrw"/></xsl:attribute> 
            <xsl:attribute name="cols"><xsl:value-of select="$xtafco"/></xsl:attribute>  
            <xsl:attribute name="onblur"><xsl:value-of select="$xtafnOnBlur"/></xsl:attribute> 
            <xsl:value-of select="$xtafva"/> 

     </xsl:element>  
      

</xsl:template>


<!-- ************************************************************** -->
<!--                                                                -->
<!--                                                                -->  
<!-- This is the deactive template rule called                      --> 
<!--     fxCheckbox                                                 --> 
<!-- which create a input type=checkbox tag                         -->
<!--                                                                -->  
<!-- Parameters                                                     -->
<!--                                                                --> 
<!--     xcbfnm          Checkbox field name                        -->
<!--     xcbfid          Checkbox field id                          -->
<!--     xcbfsi          Checkbox field subid                       -->
<!--     xcbfcc          Checkbox field Isselected                  -->
<!--     xcbfva          Checkbox field value                       -->
<!--     xcbfnOnBlur     onBlur functions                           --> 
<!--     xcbfnOnKeydown  onKeydown functions                        --> 
<!-- ************************************************************** -->

<!--

<xsl:template name = "fxCheckbox"> 


    <xsl:param name = "xcbfnm" />
    <xsl:param name = "xcbfid" />
    <xsl:param name = "xcbfsi" />
    <xsl:param name = "xcbfcc" />
    <xsl:param name = "xcbfva" />   
    <xsl:param name = "xcbfnOnClick" />
    <xsl:param name = "xcbfnOnKeydown" />
   
    <xsl:element name="input">

         <xsl:attribute name="type" >checkbox</xsl:attribute>
         <xsl:attribute name="name"><xsl:value-of select="$xcbfnm"/></xsl:attribute> 
         <xsl:attribute name="id"><xsl:value-of select="$xcbfid"/></xsl:attribute> 
         <xsl:attribute name="subid"><xsl:value-of select="$xcbfsi"/></xsl:attribute>
         <xsl:if test="$xcbfcc='Y'">   
               <xsl:attribute name="checked">checked</xsl:attribute> 
         </xsl:if>
         <xsl:attribute name="value"><xsl:value-of select="$xcbfva"/></xsl:attribute> 
         <xsl:attribute name="onclick"><xsl:value-of select="$xcbfnOnClick"/></xsl:attribute> 
         <xsl:attribute name="onkeydown"><xsl:value-of select="$xcbfnOnKeydown"/></xsl:attribute> 
         
    </xsl:element>  
                   

</xsl:template>
-->

<!-- ************************************************************** -->
<!--                                                                -->
<!--                                                                -->  
<!-- This is the template rule called                               --> 
<!--     fxRadiobutton                                              --> 
<!-- which create a input type=radiobutton tag                      -->
<!--                                                                -->  
<!-- Parameters                                                     -->
<!--                                                                --> 
<!--     xrbfnm          Radiobutton field name                     -->
<!--     xrbfid          Radiobutton field id                       -->
<!--     xrbfsi          Radiobutton field subid                    -->
<!--     xrbfis          Radiobutton field Isselected               -->
<!--     xrbfva          Radiobutton field value                    -->
<!--     xrbfnOnBlur     onBlur functions                           --> 
<!--     xrbfnOnKeydown  onKeydown functions                        --> 
<!-- ************************************************************** -->


<xsl:template name = "fxRadiobutton"> 


    <xsl:param name = "xrbfnm" />
    <xsl:param name = "xrbfid" />
    <xsl:param name = "xrbfsi" />
    <xsl:param name = "xrbfis" />
    <xsl:param name = "xrbfva" />   
    <xsl:param name = "xrbfnOnClick" />
    <xsl:param name = "xrbfnOnKeydown" />
   
    <xsl:element name="input">

         <xsl:attribute name="type" >radiobutton</xsl:attribute>
         <xsl:attribute name="name"><xsl:value-of select="$xrbfnm"/></xsl:attribute> 
         <xsl:attribute name="id"><xsl:value-of select="$xrbfid"/></xsl:attribute> 
         <xsl:attribute name="subid"><xsl:value-of select="$xrbfsi"/></xsl:attribute>
         <xsl:if test="$xrbfis='Y'">   
               <xsl:attribute name="checked">checked</xsl:attribute> 
         </xsl:if>
         <xsl:attribute name="value"><xsl:value-of select="$xrbfva"/></xsl:attribute> 
         <xsl:attribute name="onclick"><xsl:value-of select="$xrbfnOnClick"/></xsl:attribute> 
         <xsl:attribute name="onkeydown"><xsl:value-of select="$xrbfnOnKeydown"/></xsl:attribute> 
         
    </xsl:element>  
                   

</xsl:template>


<!-- ************************************************************** -->


</xsl:stylesheet> 
